BOOST_PP_TUPLE_TO_ARRAY

The BOOST_PP_TUPLE_TO_ARRAY macro converts a tuple to an array.

#### Usage

BOOST_PP_TUPLE_TO_ARRAY(size,tuple)
or
BOOST_PP_TUPLE_TO_ARRAY(...) (v)

#### Arguments

size
  The size of the tuple. Valid tuple sizes range from 1 to BOOST_PP_LIMIT_TUPLE.
tuple
  The tuple to be converted.

#### Remarks

The size argument must be the actual size of the tuple.
You can invoke the variadic version (v) as BOOST_PP_TUPLE_TO_ARRAY(tuple) or BOOST_PP_TUPLE_TO_ARRAY(size,tuple).

#### Requirements

Header: <boost/preprocessor/tuple/to_array.hpp>

#### Sample Code

    #include <boost/preprocessor/tuple/to_array.hpp>

    #define TUPLE (a,b,c)

    BOOST_PP_TUPLE_TO_ARRAY(3,TUPLE) // expands to (3, (a, b, c))

    // or for the variadic version (v)

    BOOST_PP_TUPLE_TO_ARRAY(TUPLE) // expands to (3, (a, b, c))

© Copyright Edward Diener 2011,2013

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)